# kbostadium

* Review and Amenities Information Project for All Korean Baseball Team Stadiums

### USE
```
$ jupyter lab
```

### Provided Content
* Basic Information by Stadium
* Transportation by Stadium - Directions, Bus/Subway Boarding Locations
* Food and Amenities by Stadium - Types and Locations of Parking Lots, Restaurants, Convenience Stores, Goods Stores, Restrooms, Nursing Rooms, Gate Locations
* Seating by Stadium - Characteristics, Views, Prices, Discount Information, Purchase Locations
* Next Game Recommendations Based on User's Past Visits and Preferences

### DEV
```bash
$ git clone ...
$ pdm venv create
$ source .venv/bin/activate
$ pdm install
$ pytest
```
